<?php 
// Lets keep it nice and clean.
// All variables and functions should go in magic.php which is what you're reading right now.

require('classes/errordisplay.class.php');

// Create a connection with the NNTPGrab server if there isn't one already
if (!nntpgrab_get_is_connected()) {
    $hostname = "";
    $port = -1;
    get_hostname_and_port($hostname, $port);
    nntpgrab_connect($hostname, $port, "", "", false);    // Ignore possible connection problems. These should be handled at other places
}

// ****************************************************************************************** //
/* Retrieve the hostname and port on which the NNTPGrab server is running */
function get_hostname_and_port(&$hostname, &$port)
{
    if (!file_exists("./config.ini")) {
        new errordisplay('critical',"Fatal error: the file 'config.ini' could not be found!");
    }

    $config = parse_ini_file("./config.ini", true);

    if (!isset($config["connection"]) ||
        !isset($config["connection"]["hostname"]) ||
        !isset($config["connection"]["port"])) {
            
            new errordisplay('critical',"Fatal error: The file 'config.ini' isn't complete. Please reinstall");
    }

    $hostname = $config["connection"]["hostname"];
    $port = intval($config["connection"]["port"]);

    unset($config);
}

// ****************************************************************************************** //
/* Check schedular status, if its running it can only be stopped
   else (its stopping or stopped) it can only be started again.
   Change the icons and strings for the controls while you're at it */
function toggleSchedular()
{
    if (nntpgrab_schedular_get_state() == "0") {
        nntpgrab_schedular_stop(false);
    } else {
        nntpgrab_schedular_start();
    }
}

// ****************************************************************************************** //
/* This function shows a nice error message in case there is no connection
   with the NNTPGrab server */
function test_is_connected()
{
    if (!nntpgrab_get_is_connected()) {
        new errordisplay('critical',"There is no connection with the NNTPGrab server at the moment.<br />\n
                                     Please go to the info tab to see more details.\n");
    }
}

// ****************************************************************************************** //
/* Test if the file is already downloaded and can be reached by the webserver */
function test_is_already_downloaded($collection_name, $filename)
{
    static $config_opts = 0;

    if (!$config_opts) {
        $config_opts = nntpgrab_config_get_opts();
    }

    if (strlen($filename) == 0) {
        return FALSE;
    }

    return file_exists($config_opts["download_directory"] . "/" . $collection_name . "/" . $filename);
}

?>
