<?php
define("FONTFILE", dirname(__FILE__) . "/LiberationSans-Regular.ttf");

function average_speed($speeddata) 
{
    return array_sum($speeddata) / count($speeddata);
}

function load_stats($filename)
{
    if (!file_exists($filename)) {
        return FALSE;
    }
    
    $fp = fopen($filename, "r");
    if (!$fp) {
        return FALSE;
    }
    
    $now = NULL;
    $i = 0;
    while (!feof($fp)) {
        $d = fgets($fp, 8192);
        list($time,$speed) = explode(":", $d);
        if (strlen(trim($d)) == 0) continue;
        if ($now == NULL) {
            $now = $time;
            $speed_now = $speed;
        }
        $speeds[$time] = trim($speed);
        $i++;
        if ($i >= 299) break;
    }
    $speeds[0] = 0;
    return array($speeds, $now, $speed_now);
}

function stats2graph(&$img, $speeds, $now, $speed_now, $graphcolor, $textcolor, $scale, $x_offset = 0, $y_offset = 0)
{
    $previousx = NULL;
    $previousy = NULL;
    
    for ($i = 0; $i <= 300; $i++) {
        if (!isset($speeds[$now - $i]) || $speeds[$now - $i] === NULL) {
            $curspeed = $previousspeed;         
            // TODO: Average?
        } else {
            $curspeed = $speeds[$now - $i];
        }
    
        $x = (300 - $i) * 2 +  $x_offset;
        $y = 100 - $curspeed / $scale * 80 - 10 + $y_offset;
        
        if ($previousx !== NULL && $previousy !== NULL) {
            imageline($img, $x, $y, $previousx, $previousy, $graphcolor);
        }
        
        $previousspeed = $curspeed;
        $previousx = $x;
        $previousy = $y;
    }
    imagettftext($img, 10, 0, 0 + $x_offset, 60 + $y_offset, $textcolor, FONTFILE, "Avg speed (5min): " . round(average_speed($speeds) / 1024, 1) . " KB/s");
    imagettftext($img, 10, 0, 0 + $x_offset, 75 + $y_offset, $textcolor, FONTFILE, "Cur speed (1sec): " . round($speed_now / 1024, 1) . " KB/s");
}

$img = imagecreatetruecolor (600, 100);

// Define some colors
$green = imagecolorallocate($img, 0, 255, 0);
$white = imagecolorallocate($img, 255, 255, 255);

include "rawdlstats.php";
list($speeds, $now, $speed_now) = load_stats("dlstats.txt");
$scale = max($speeds);
stats2graph($img, $speeds, $now, $speed_now, $green, $white, $scale);

// Add "last updated" line
imagefttext($img, 10, 0, 5, 15, $white, FONTFILE, "Last updated: " . date("H:i:s"));

// No error-reporting when outputting to gif
error_reporting(0);

// Create image
header("Content-type: image/png");
imagepng($img);
?>
